@@ -1,11 +1,12 @@
 import importlib
 from typing import TypeVar, Generic, Callable, Union, Any, cast, Iterator
 from types import ModuleType  # noqa
+from pathlib import Path
 
 import amino  # noqa
 from amino import boolean
 from amino.func import I
-from amino.tc.base import Implicits
+from amino.tc.base import F
 from amino.util.mod import unsafe_import_name
 from amino.tc.monoid import Monoid
 from amino.util.string import ToStr
@@ -21,12 +22,12 @@ class ImportFailure(ToStr):
 
 class ImportException(ImportFailure):
 
-    def __init__(self, exc: Exception) -> None:
+    def __init__(self, desc: str, exc: Exception) -> None:
+        self.desc = desc
         self.exc = exc
 
-    @property
     def _arg_desc(self) -> 'amino.List[str]':
-        return amino.List(str(self.exc))
+        return amino.List(self.desc, str(self.exc))
 
 
 class InvalidLocator(ImportFailure):
@@ -34,33 +35,32 @@ class InvalidLocator(ImportFailure):
     def __init__(self, msg: str) -> None:
         self.msg = msg
 
-    @property
     def _arg_desc(self) -> 'amino.List[str]':
         return amino.List(self.msg)
 
 
-class Either(Generic[A, B], Implicits, implicits=True):
+class Either(Generic[A, B], F[B], implicits=True):
 
     def __init__(self, value: Union[A, B]) -> None:
         self.value = value
 
     @staticmethod
-    def import_name(mod: str, name: str) -> 'Either[ImportFailure, Any]':
+    def import_name(mod: str, name: str) -> 'Either[ImportFailure, B]':
         try:
             value = unsafe_import_name(mod, name)
         except Exception as e:
-            return Left(ImportException(e))
+            return Left(ImportException(f'{mod}.{name}', e))
         else:
             return Left(InvalidLocator(f'{mod} has no attribute {name}')) if value is None else Right(value)
 
     @staticmethod
-    def import_path(path: str) -> 'Either[ImportFailure, Any]':
+    def import_path(path: str) -> 'Either[ImportFailure, B]':
         from amino.list import List
         return (
             List.wrap(path.rsplit('.', 1))
             .lift_all(0, 1)
             .to_either(InvalidLocator(f'invalid module path: {path}'))
-            .flat_map2(lambda a, b: Either.import_name(a, b).lmap(ImportException))
+            .flat_map2(lambda a, b: Either.import_name(a, b).lmap(lambda a: ImportException(path, a)))
         )
 
     @staticmethod
@@ -68,10 +68,26 @@ class Either(Generic[A, B], Implicits, implicits=True):
         try:
             mod = importlib.import_module(modname)
         except Exception as e:
-            return Left(ImportException(e))
+            return Left(ImportException(modname, e))
         else:
             return Right(mod)
 
+    @staticmethod
+    def import_from_file(path: Path, name: str) -> 'Either[ImportFailure, B]':
+        try:
+            spec = importlib.util.spec_from_file_location('temp', str(path))
+            module = importlib.util.module_from_spec(spec)
+            spec.loader.exec_module(module)
+        except Exception as e:
+            return Left(ImportException(f'{path}.{name}', e))
+        else:
+            attr = getattr(module, name, None)
+            return (
+                Left(InvalidLocator(f'{path} has no attribute {name}'))
+                if attr is None else
+                Right(attr)
+            )
+
     @property
     def is_right(self) -> 'amino.Boolean':
         return boolean.Boolean(isinstance(self, Right))
@@ -165,6 +181,12 @@ class Either(Generic[A, B], Implicits, implicits=True):
             return Monoid.fatal(type(v)).combine(self.__left_value, v)
         return f().lmap(acc) if self.is_left else self
 
+    def filter_with(self, f: Callable[[B], bool], g: Callable[[B], C]) -> 'Either[C, B]':
+        return self // (lambda a: Right(a) if f(a) else Left(g(a)))
+
+    def left_contains(self, a: A) -> 'boolean.Boolean':
+        return boolean.Boolean(self.is_left and self.__left_value == a)
+
 
 class Right(Either):
 
