@@ -1,9 +1,10 @@
-from functools import wraps, partial, singledispatch
+from functools import wraps, partial
 from inspect import getfullargspec
-import typing
-from typing import Callable, Union, Any, Dict
+from typing import Callable, Union, Any, TypeVar, Tuple
 
-from amino.util.string import snake_case
+A = TypeVar('A')
+B = TypeVar('B')
+C = TypeVar('C')
 
 
 def curried(func):
@@ -66,34 +67,13 @@ def call_by_name(b: CallByName):
     return b() if callable(b) else b
 
 
-def dispatch(obj: Any, tpes: typing.List[type], prefix: str, default: Callable=None) -> Any:
-    @singledispatch
-    def main(o, *a, **kw):
-        if default is None:
-            msg = 'no dispatcher defined for {} on {} {}'
-            raise TypeError(msg.format(o, obj.__class__.__name__, prefix))
-        else:
-            default(o, *a, **kw)
-    for tpe in tpes:
-        fun = getattr(obj, '{}{}'.format(prefix, snake_case(tpe.__name__)))
-        main.register(tpe)(fun)
-    return main
-
-
-def dispatch_with(rules: Dict[type, Callable], default: Callable=None):
-    @singledispatch
-    def main(o, *a, **kw):
-        if default is None:
-            msg = 'no dispatcher defined for {} {} ({})'
-            raise TypeError(msg.format(type(o), o, rules))
-        else:
-            default(o, *a, **kw)
-    for tpe, fun in rules.items():
-        main.register(tpe)(fun)
-    return main
-
 def is_not_none(a):
     return a is not None
 
-__all__ = ('curried', 'F', 'I', 'flip', 'call_by_name', 'Val', 'ReplaceVal',
-           'dispatch', 'dispatch_with', 'is_not_none')
+
+def tupled2(f: Callable[[A, B], C]) -> Callable[[Tuple[A, B]], C]:
+    def wrap(a: Tuple[A, B]) -> C:
+        return f(a[0], a[1])
+    return wrap
+
+__all__ = ('curried', 'I', 'flip', 'call_by_name', 'Val', 'ReplaceVal', 'is_not_none', 'tupled2')
