@@ -10,6 +10,7 @@ from amino.lazy import lazy
 from amino.logging import amino_root_logger
 
 A = TypeVar('A')
+TC = TypeVar('TC', bound='TypeClass')
 
 
 class TypeClassMeta(GenericMeta):
@@ -36,6 +37,9 @@ class TypeClassMeta(GenericMeta):
     def m_for(self, a: Any) -> 'amino.maybe.Maybe[TypeClass]':
         return self.m(type(a))
 
+    def e_for(self, a: A) -> 'amino.either.Either[str, TC]':
+        return self.m_for(a).to_either(f'no `{self.__name__}` instance for {type(a)}')
+
     def exists_instance(self, tpe: type) -> bool:
         return self.m(tpe).present
 
@@ -225,7 +229,7 @@ class Implicits(metaclass=ImplicitsMeta):
 
     @property
     def dbg(self) -> Any:
-        amino_root_logger.verbose(self)
+        amino_root_logger.test(self)
         return self
 
     @property
@@ -245,6 +249,10 @@ class GlobalTypeClasses(TypeClasses):
         return Map({Show: Show(), Tap: Tap()})
 
 
+class F(Generic[A], Implicits):
+    pass
+
+
 TC = GlobalTypeClasses()
 
 
