@@ -1,6 +1,6 @@
 from traceback import format_tb
 
-from amino import List, Lists
+from amino import List, Lists, Maybe
 
 
 def sanitize_tb(tb: List[str]) -> List[str]:
@@ -9,6 +9,8 @@ def sanitize_tb(tb: List[str]) -> List[str]:
 
 def format_exception(exc: Exception) -> List[str]:
     tb = sanitize_tb(Lists.wrap(format_tb(exc.__traceback__)))
-    return tb.cat(f'{exc.__class__.__name__}: {exc}')
+    main = tb.cat(f'{exc.__class__.__name__}: {exc}')
+    cause = Maybe(exc.__cause__) / format_exception / (lambda a: a.cons('Cause:')) | List()
+    return main + cause
 
 __all__ = ('sanitize_tb', 'format_exception')
