@@ -1,8 +1,10 @@
 import re
 import abc
-from typing import Any
+from typing import Any, Callable
 from functools import singledispatch
 
+from hues import huestr
+
 import amino
 
 
@@ -36,9 +38,11 @@ def decode_exc(value: Exception) -> str:
     return decode_list(value.args).head | str(value)
 
 
-def camelcaseify(name: str, sep: str='', splitter: str='_') -> str:
+def camelcase(name: str, sep: str='', splitter: str='_') -> str:
     return sep.join([n.capitalize() for n in re.split(splitter, name)])
 
+camelcaseify = camelcase
+
 
 def safe_string(value: Any) -> str:
     try:
@@ -52,15 +56,43 @@ def safe_string(value: Any) -> str:
 
 class ToStr(abc.ABC):
 
-    @abc.abstractproperty
+    @abc.abstractmethod
     def _arg_desc(self) -> 'amino.List[str]':
         ...
 
     def __str__(self) -> str:
-        args = self._arg_desc.join_comma
+        args = self._arg_desc().join_comma
         return f'{self.__class__.__name__}({args})'
 
     def __repr__(self) -> str:
         return str(self)
 
-__all__ = ('snake_case', 'decode', 'camelcaseify')
+
+def col(a: Any, c: Callable[[huestr], huestr]) -> str:
+    return c(huestr(str(a))).colorized
+
+
+def red(a: Any) -> str:
+    return col(a, lambda a: a.red)
+
+
+def green(a: Any) -> str:
+    return col(a, lambda a: a.green)
+
+
+def yellow(a: Any) -> str:
+    return col(a, lambda a: a.yellow)
+
+
+def blue(a: Any) -> str:
+    return col(a, lambda a: a.blue)
+
+
+def cyan(a: Any) -> str:
+    return col(a, lambda a: a.cyan)
+
+
+def magenta(a: Any) -> str:
+    return col(a, lambda a: a.magenta)
+
+__all__ = ('snake_case', 'decode', 'camelcaseify', 'red', 'green', 'yellow', 'blue', 'cyan', 'magenta', 'camelcase')
